/**
 * Copyright 2011 Xeiam LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.xeiam.sundial;

import org.quartz.InterruptableJob;
import org.quartz.JobExecutionContext;
import org.quartz.exceptions.JobExecutionException;
import org.quartz.exceptions.UnableToInterruptJobException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.xeiam.sundial.exceptions.JobInterruptException;
import com.xeiam.sundial.exceptions.RequiredParameterException;

/**
 * @author timmolter
 */
public abstract class Job extends JobContainer implements InterruptableJob {

  private final Logger logger = LoggerFactory.getLogger(Job.class);

  /**
   * Required no-arg constructor
   */
  public Job() {

    // this is a comment.
  }

  @Override
  public final void execute(JobExecutionContext pJobExecutionContext) throws JobExecutionException {

    // check for global lock
    if (SundialJobScheduler.getGlobalLock()) {
      logger.info("Global Lock in place! Job aborted.");
      return;
    }

    try {

      initContextContainer(pJobExecutionContext);

      doRun();

    } catch (RequiredParameterException e) {
    } catch (JobInterruptException e) {
    } catch (Exception e) {
      logger.error("Error executing Job! Job aborted!!!", e);
    } finally {
      cleanup();
      destroyContext(); // remove the JobContext from the ThreadLocal
    }

  }

  @Override
  public void interrupt() throws UnableToInterruptJobException {

    setTerminate();
    logger.info("Interrupt called!");

  }

  /**
   * Override and place any code in here that should be called no matter what after the Job runs or throws an exception.
   */
  public void cleanup() {

  }

  public abstract void doRun() throws JobInterruptException;

}
